import requests

def aksconverter(base, to , amount):
		url = "https://anyapi.io/api/v1/exchange/convert?apiKey=pg2hovi5anohf0unsi656obkus8dfi43o9a6t6e735sg8v5p187n33&base="+base+"&to="+to+"&amount="+amount
		payload = {}
		headers = {}
		response = requests.request("GET", url, headers=headers, data=payload)
		print(response.text)
		return response.text

